import * as fs from 'fs';
import * as path from 'path';
import { normalizePath } from 'vite';
import { createRequire } from 'node:module';
const require = createRequire(import.meta.url);
export function getMatchingContentFilesWithFrontMatter(workspaceRoot, rootDir, glob) {
    // eslint-disable-next-line @typescript-eslint/no-var-requires
    const fg = require('fast-glob');
    // eslint-disable-next-line @typescript-eslint/no-var-requires
    const fm = require('front-matter');
    const root = normalizePath(path.resolve(workspaceRoot, rootDir));
    const resolvedDir = normalizePath(path.relative(root, path.join(root, glob)));
    const contentFiles = fg.sync([`${root}/${resolvedDir}/*`], {
        dot: true,
    });
    const mappedFilesWithFm = contentFiles.map((f) => {
        const fileContents = fs.readFileSync(f, 'utf8');
        const raw = fm(fileContents);
        const filepath = f.replace(root, '');
        const match = filepath.match(/\/([^/.]+)(\.([^/.]+))?$/);
        let name = '';
        let extension = '';
        if (match) {
            name = match[1];
            extension = match[3] || ''; // Using an empty string if there's no extension
        }
        return {
            name,
            extension,
            path: resolvedDir,
            attributes: raw.attributes,
        };
    });
    return mappedFilesWithFm;
}
//# sourceMappingURL=get-content-files.js.map